/*
 The software in this package is distributed under the GNU General
 Public License version 2 (with a special exception described below).

 A copy of GNU General Public License (GPL) is included in this distribution,
 in the file COPYING.GPL.

 As a special exception, if other files instantiate templates or use macros
 or inline functions from this file, or you compile this file and link it
 with other works to produce a work based on this file, this file
 does not by itself cause the resulting work to be covered
 by the GNU General Public License.

 However the source code for this file must still be made available
 in accordance with section (3) of the GNU General Public License.

 This exception does not invalidate any other reasons why a work based
 on this file might be covered by the GNU General Public License.
 */

#include "config/option/configfileoption.h"

#include <iostream>

#include <logfunc.hpp>

using namespace std;
using boost::program_options::value;
using boost::program_options::variables_map;
using I2n::Logger::GlobalLogger;

//-----------------------------------------------------------------------------
// ConfigFileOption
//-----------------------------------------------------------------------------

/**
 * @brief Default constructor.
 */
ConfigFileOption::ConfigFileOption() :
    ConfigurationOption(
        "config-file",
        value<string>()->default_value( "/etc/pingcheck.conf" ),
        "Name of the configuration file."
    )
{
}

/**
 * @brief Destructor.
 */
ConfigFileOption::~ConfigFileOption()
{
}

bool ConfigFileOption::parse(
        const variables_map& vm,
        Configuration *configuration
)
{
    // config-file
    if ( 1 <= vm.count( get_command_string() ) )
    {
        string config_file_name = vm[ get_command_string() ].as<string> ();
        configuration->set_config_file_name( config_file_name );

        GlobalLogger.info() << get_command_string() << "=" << config_file_name << endl;
        return true;
    }

    return false;
}
